/*
      This file is part of GNUnet

      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
      by the Free Software Foundation; either version 2, or (at your
      option) any later version.

      GNUnet is distributed in the hope that it will be useful, but
      WITHOUT ANY WARRANTY; without even the implied warranty of
      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
      General Public License for more details.

      You should have received a copy of the GNU General Public License
      along with GNUnet; see the file COPYING.  If not, write to the
      Free Software Foundation, Inc., 59 Temple Place - Suite 330,
      Boston, MA 02111-1307, USA.
 */


/**
 * @file dht-query.c
 * @brief perform DHT operations (insert, lookup, remove)
 * @author Christian Grothoff
 *
 * FIXME: needs to be implemented
 */

#include "platform.h"
#include "gnunet_util.h"
#include "gnunet_dht_lib.h"

static void printHelp() {
  static Help help[] = {
    HELP_CONFIG,
    HELP_HELP,
    HELP_LOGLEVEL,
    HELP_VERSION,
    HELP_END,
  };
  formatHelp("dht-join [OPTIONS] TABLE-ID",
	     "Join a DHT table.",
	     help);
}

static int parseOptions(int argc,
			char ** argv) {
  int c;  

  while (1) {
    int option_index = 0;
    static struct GNoption long_options[] = {
      LONG_DEFAULT_OPTIONS,
      { 0,0,0,0 }
    };
    c = GNgetopt_long(argc,
		      argv,
		      "vhH:c:L:d",
		      long_options, 
		      &option_index);    
    if (c == -1) 
      break;  /* No more flags to process */
    if (YES == parseDefaultOptions(c, GNoptarg))
      continue;
    switch(c) {
    case 'v': 
      printf("dht-join v0.0.0\n");
      return SYSERR;
    case 'h': 
      printHelp(); 
      return SYSERR;
    default:
      LOG(LOG_FAILURE,
	  "Unknown option %c. Aborting. "
	  "Use --help to get a list of options.\n",
	  c);
      return SYSERR;
    } /* end of parsing commandline */
  } /* while (1) */
  if (argc - GNoptind != 1) {
    LOG(LOG_WARNING, 
	"Not enough arguments. "
	"You must specify a TABLE-ID\n");
    printHelp();
    return SYSERR;
  }
  FREENONNULL(setConfigurationString("DHT-JOIN",
				     "TABLE",
				     argv[GNoptind++]));
  return OK;
}

int main(int argc, 
	 char **argv) {
  char * tableName;

  if (SYSERR == initUtil(argc, argv, &parseOptions)) 
    return 0;

  tableName = getConfigurationString("DHT-JOIN", 
				     "TABLE");

  
  DHT_LIB_init();
  initializeShutdownHandlers();
  if (OK != DHT_LIB_join(NULL,
			 NULL,
			 0,
			 0))
    return 1;
  wait_for_shutdown();
  doneShutdownHandlers();
  DHT_LIB_done();
  return 0;
}

/* end of dht-join.c */
